# Igorskis Framework

Igorskis Framework — это веб-фреймворк для создания веб-приложений.

Чтобы создать веб-приложение, ты можешь использовать команду:
```sh
igorskis-admin startproject project_name
```

### Определение маршрутов
Ты можешь создавать URL-адреса в `urls.py` командой:
```python
router.add_route(path, view)
```

### Контроллеры (views)
В `views.py` можно создавать функции для рендеринга страниц. Пример:
```python
def index():
    return html("index.html")
```
Создай файл `html/index.html` и добавь в него HTML-код.

Также можно передавать параметры в функцию `html`. Пример:
```python
html("index.html", name="John Doe")
```
В таком случае в `html/index.html` ты можешь использовать переменную `name` так:
```html
{{ name }}
```

### Работа с моделями
В `models.py` можно создавать модели. Пример:
```python
class User(Model):
    def __init__(self, name, email):
        super().__init__(name=name, email=email)
```
В моделях можно использовать методы:
- `get_all()`
- `update()`
- `delete()`

Чтобы создать экземпляр модели:
```python
user = User(name="John Doe", email="9K9bM@example.com")
```
Чтобы добавить экземпляр модели в базу данных, вызови метод:
```python
user.save()
```

### Статические файлы
Картинки, CSS-стили и JavaScript-скрипты добавляются в папку `static/`.

Есть CORS.
Есть файл `settings.py` с настройками. (Пока настраивается только `STATIC_URL`. Эта настройка нужна для обслуживания статических файлов.)

### Запуск сервера
Ты можешь запустить сервер командой:
```sh
igorskis-admin runproject True
```
Параметр `True` используется для отладки. Если он установлен в `False`, то сервер запускается в без отладки.
Также вместо `True` можно использовать `1`, `on`, `t`, `y` или `yes`.
Вместо `False` можно использовать `0`, `off`, `f`, `n` или `no`.

### Продакшн-запуск сервера
Ты можешь запустить продакшн-версию сервера командой:
```sh
gunicorn -w 4 -b 0.0.0.0:8000 server:app
```
-w 4 - это количество воркеров. -b 0.0.0.0:8000 - это адрес сервера.

При этом ты должен находиться в директории проекта. Gunicorn устанавливается во время установки igorskis-framework по умолчанию.

### Что новое в версии 1.0.2
- Добавлена дефолтная страница. Просто запусти сервер и переходи по адресу http://localhost:8000/ чтобы увидеть её.
- Добавлена возможность запуска сервера в продакшн-режиме. (Абзац Продакшн-запуск сервера)
- Добавлена команда `igorskis-admin runproject [debug]`. (Абзац Запуск сервера)
